Link

Struct Link 

pub struct Link<'a>(/* private fields */);

Implementations

Source

impl<'a> Link<'a>

Builder for link files

pub fn targeting(target: &'a Path) -> Self

Prepares a new link that when opened runs the given executable.

pub fn set_name(&mut self, name: &'a str) -> &mut Self

Updates the display name for this link.

pub fn set_icon(&mut self, icon: &'a Path) -> &mut Self

Updates the path to the icon to use for this link

pub fn set_arguments(&mut self, arguments: &'a str) -> &mut Self

Updates the arguments to be passed to the program when started

pub fn set_working_directory( &mut self, working_directory: &'a Path, ) -> &mut Self

Updates the working directory for this link.

pub fn save(&mut self, at: &Path) -> Result<(), Error>

Saves the link at the specified location.

If a file extension is necessary for the platform, it will be appended to the path.

Errors

The specific errors depend on the platform, but if there is an error, the link won’t be saved.

pub fn save_to_menu(&mut self, name: &OsStr) -> Result<(), Error>

Makes the link available to the platform’s conventional application menu.

Errors

The specific errors depend on the platform, but if there is an error, the link won’t be saved.